VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
  Persistable = 0  'NotPersistable
  DataBindingBehavior = 0  'vbNone
  DataSourceBehavior  = 0  'vbNone
  MTSTransactionMode  = 0  'NotAnMTSObject
END
Attribute VB_Name = "clsUserState"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = False
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = False
Option Explicit

Public Filter     As String
Public Publishers As Collection

Private mUserID As String

Private Sub Class_Initialize()
    Set Publishers = New Collection
End Sub

Public Property Get UserID() As String
    UserID = mUserID
End Property
Public Property Let UserID(ByVal lUserID As String)
    mUserID = lUserID
    ' Generate a new UserID if none exists.
    If mUserID = "" Then
        Randomize
        mUserID = Format(Now, "yyyymmddHhNnSs") & Format(Rnd * 99999, "00000")
    End If
End Property

Private Property Get StateFileName() As String
    StateFileName = App.Path & "\" & mUserID & ".usf"
End Property

' Saves all state information to a simple CSV file.
Public Sub SaveState()
    Dim lFileNbr   As Integer
    Dim lPubState  As clsPubState
    
    lFileNbr = FreeFile
    Open StateFileName For Output As lFileNbr
    
    ' Save the state data.
    Write #lFileNbr, Filter
    Write #lFileNbr, Publishers.Count
    For Each lPubState In Publishers
        Write #lFileNbr, lPubState.PubID, lPubState.Name, lPubState.Phone
    Next lPubState
    
    Close lFileNbr
End Sub

' Attempts to restore the state information from the CSV file.
' If the state file is not found, or the data in the file hasn't
' been used in the last 60 minutes, then we assume a new session.
Public Sub GetState()
    Dim lFileNbr   As Integer
    Dim lNbrPubs   As Long
    Dim lIndex     As Long
    Dim lID        As Long
    Dim lName      As String
    Dim lPhone     As String
    Dim lPubState  As clsPubState
        
    Filter = ""
    Set Publishers = New Collection
    lFileNbr = FreeFile
    
    On Error Resume Next
    Open StateFileName For Input As lFileNbr
    
    'If file not found, then that means no state information exists.
    If Err.Number = 53 Then ' 53 = File Not Found.
        Exit Sub
    ElseIf Err.Number <> 0 Then
        Call Err.Raise(Err.Number, Err.Source, Err.Description)
    End If
    
    On Error GoTo 0 ' Reset error handling so run-time errors get raised.
    
    ' If state information is > 60 minutes old, then ignore it.
    If DateDiff("n", FileDateTime(StateFileName), Now) > 60 Then
        Close lFileNbr
        Exit Sub
    End If
    
    ' Get the state data.
    Input #lFileNbr, Filter
    Input #lFileNbr, lNbrPubs
    For lIndex = 1 To lNbrPubs Step 1
        Set lPubState = New clsPubState
        ' Note the syntax of the Input statement won't allow us to input
        ' directly into an object's properties so instead we have to input
        ' into local variables and then assign to the object.
        Input #lFileNbr, lID, lName, lPhone
        lPubState.PubID = lID
        lPubState.Name = lName
        lPubState.Phone = lPhone
        Call Publishers.Add(lPubState)
    Next lIndex
    
    Close lFileNbr
End Sub

